@@ -1,6 +1,7 @@
-from .query import *
+from .other import *
 from .numanip import *
 from .arraymanip import *
 from .figmanip import *
 from .filemanip import *
+from .vectormanip import *
 # from .xlsx import *
\ No newline at end of file
