@@ -1,3 +1,3 @@
 # from .core import *
 # from .advanced import *
-from .scs import *
\ No newline at end of file
+# from .scs import *
\ No newline at end of file
